/* 
 Copyright by The HDF Group.
 All rights reserved.                                                      
                                                                           
 This file is part of the HDF-EOS5 Augmentation Tool. The full HDF-EOS5 
 Augmentation Tool copyright notice including terms governing use, modification,
 and redistribution, is contained in the file COPYING.     
 COPYING can be found at the root of the source code    
 distribution tree. If you do not have access to this file, you may request
 a copy from eoshelp@hdfgroup.org. 
*/
#include <stdio.h>
#include <unistd.h>
#include "run.h"

extern char *optarg;
extern int optind;
extern int optopt;

int main(int argc, char **argv)
{

  /* augmentmethod reflects 3 solutions documented by an investigation report.
   The document can be found under 
   http://hdfeos.org/software/aug_eos5/doc/Investigation%20Report%20for%20Allowing%20netCDF-4%20to%20Access%20HDF-EOS5%20Files.pdf
   Finally only solution 1 was accepted although the tool also implemented other two solutions.
   Only solution 1 is used by NASA and we only test solution 1.
  */
  int augmentmethod = 1;

  /* Which option to use, index(i), file(f) or default. */
  int input_option = -1;
  
  /* This is the user-provided file that gives the relation between the dimension and the coordinate variable 
     This file is only valid for the -f option. Check the readme or usage at http://hdfeos.org/software/aug_eos5/
     for more information.
  */
  char *dimgeonames=NULL;

  /* Don't print log info. if this variable is not 0. Eventually this can be a configuration option. */
  int no_log_info = 1;

  /* aug_choice can be 'i'(for the index option) or 'f' (for the file option) or default
     Check the readme or usage at http://hdfeos.org/software/aug_eos5/
     for more information.
  */
  int aug_choice = 0;

  /* For MacOS 10.8, getopt doesn't assign optopt to 0 even the desired values are found.
     So to deal with this issue, a special flag to work around the issue on Mac is used.*/ 
  int port_mac_flag = 0;

  while ((input_option = getopt(argc, argv, "if:")) != -1) {
    switch (input_option) {
      case 'i':
	aug_choice = 1;
        port_mac_flag = 1;
	break;
      case 'f':
	aug_choice = 2;
	dimgeonames = optarg;
        port_mac_flag =2;
	break;
    }
  }

  /* If the option doesn't start with a '-', print the usage and exit the program. */
  /*From gnu site, optind: This variable is set by getopt to the index of the next element of the argv array to be processed */
  /* If the options argument string begins with a hyphen (‘-’), this is treated specially. It permits arguments that are not options to be returned as if they were associated with option character ‘\1’. */
  
  if (optind + 1 != argc) {
    usage();
    return 1;
  }

  /* If the option after - is not i or f, print the usage and exit the program. */
  if(optopt != 0 ) {
    
    /* For Mac OS 10.8, optopt is not 0 even if everything is right. So by-pass this.*/
    if(port_mac_flag == 0) {
       usage();
       return 1;
    }
  }

  /*if(dimgeonames==NULL)
    fprintf(stderr, "WARNING: -f switch (dimension name to geo field or file name mapping) is not being used.\n");*/

  int succeeded = aug_eos5(argv[optind], augmentmethod, dimgeonames, no_log_info, aug_choice);

  if(succeeded == 0) 
    printf("%s has been successfully augmented.\n", argv[optind]);

  return succeeded; /* aug_eos5(argv[optind], augmentmethod, dimgeonames, no_log_info, choice); */
}

// vim:ts=8:sw=2:sts=2:cindent
