/* 
 Copyright by The HDF Group.
 All rights reserved.                                                      
                                                                           
 This file is part of the HDF-EOS5 Augmentation Tool. The full HDF-EOS5 
 Augmentation Tool copyright notice including terms governing use, modification,
 and redistribution, is contained in the file COPYING.     
 COPYING can be found at the root of the source code    
 distribution tree. If you do not have access to this file, you may request
 a copy from eoshelp@hdfgroup.org. 
*/
#ifndef DUMP_WRITE_H
#define DUMP_WRITE_H

#include "util.h"

/* Open HDF5 file */
int open_hdf5(hid_t ctxid, const char *fname);

/* Create the augmented group */
int create_aug_group(hid_t ctxid, const char *gridswathname, int isgrid);

/* Create the HDF5 dimension scale dataset when horizontal dimension names of a grid are XDim and YDim.*/
int write_hdf5_dimension(hid_t ctxid, const char *gridswathname, int isgrid, int ispure, const dimension_t *dim,const namelistalloc *ext_dimnames, const int aug_option);

/* Create the HDF5 dimension scale dataset when horizontal dimension names of a grid are not XDim and YDim. */
int write_hdf5_implicit_dimension(hid_t ctxid, const char *gridname, const grid_t *grid, int isxdim, int ispure, const int aug_option);

/* Associate the HDF5 dimension with the dimension scale*/
int associate_hdf5_dimension(hid_t ctxid, const char *gridswathname, int isgrid, const fieldinfo_t *field, int isdatafield);

/* Fill HDF5 dimension values to the 1-D dimension */
//int fill_hdf5_1d_dimension(hid_t ctxid, const char *gridname, int islongitude, const doublealloc *coord, const dimension_t *dim, const int aug_option);
int fill_hdf5_1d_dimension(hid_t ctxid, const grid_t *grid, const char *gridname, int islongitude,const doublealloc *coord,  const int aug_option);

/* Fill HDF5 dimension value for the third dimension */
int fill_hdf5_1d_3rd_dimension(hid_t ctxid, const char *gridname, const dimension_t *dim,const int aug_option);

/* Fill HDF5 dimension value for the case when the lat/lon are 2D */
int fill_hdf5_2d_dimension(hid_t ctxid, const char *gridname, int islongitude, const doublealloc *coord, int ydimmajor, long xsize, long ysize);

/* The following four routines are to address the conformation to the CF conventions */

/* For the 1-D lat/lon HDF-EOS grid case, make sure the units for XDim and YDim  
   to follow CF and the long_name to be latitude and longitude. */
int conform_cf_conventions_grid_1d(hid_t ctxid, const char *gridname, int islongitude);

/* For the 2-D lat/lon HDF-EOS grid case, make sure the axis and long_name for the dimension scales to follow CF 1.5 or
   1.6 section 5.2 . */
int conform_cf_conventions_grid_2d_dim(hid_t ctxid, const char *gridname, int islongitude);

/* For the 2-D lat/lon HDF-EOS grid case, make sure the units for lat and lon   
   to follow CF and the long_name to be latitude and longitude. The "coordinates" attribute value is also generated. */
int conform_cf_conventions_grid_2d_coordvar(hid_t ctxid, const char *gridname, int islongitude, challoc *coordinates);

/* For the 2-D lat/lon HDF-EOS grid case, make sure the units for data fields to add the "coordinates" attribute */
int conform_cf_conventions_2d_data(hid_t ctxid, const char *gridswathname, int isgrid, const fieldinfo_t *field, const challoc *coordinates);


/* Close HDF5 */
int close_hdf5(hid_t ctxid);

/* Fill HDF-EOS5 swath with dimension */
int fill_hdf5_swath_dimension(hid_t ctxid, const char *gridswathname, const dimension_t *dim, const int aug_option);

#endif

// vim:ts=8:sw=2:sts=2:cindent
