#!/bin/sh 

AUGMENT() {
   case "$1" in
   -f)
        echo "Augment $3 with the <File> option"
        valgrind --leak-check=full ../../../src/aug_eos5 $1 $2 $3 2>> ../../val-file.out 
        ;;
   -i) 
        echo "Augment $3 with the <Index> option "
        valgrind --leak-check=full ../../../src/aug_eos5 $1  $3  2>> ../../val-index.out
        ;;
    esac
    if [ "$?" -ne "0" ]
    then
                cp tmp_file_backup/*.he5 .
                rm -rf tmp_file_backup
                echo "FAILED"
                echo "During the augmentation, one NASA HDF-EOS5 file with the file or the index option failed."
                exit 1
    fi

}

COMPARE() {
   echo "Compare $1 with the corresponding expected file "
   h5diff -q $1 ./augmented_files/$2
   if [ "$?" -ne "0" ]
        then
                cp tmp_file_backup/*.he5 .
                rm -rf tmp_file_backup
                echo "FAILED"
                echo "During the comparison, one NASA HDF-EOS5 file with the file or the index option failed."
                exit 1
        fi
        echo "OK"

}

TEST() {

AUGMENT $1 $2 $3
COMPARE $3 $4

}

cd file_index_option

echo "***********************************************"
echo "Test the file and index options with NASA files"
echo "***********************************************"

mkdir tmp_file_backup
cp *.he5 tmp_file_backup

echo "1.  MLS/HIRDLS files"
echo "1.1 MLS single swath "
TEST -f MLS-Aura_L2GP-BrO_v02-23-c01_2010d255.txt MLS-Aura_L2GP-BrO_v02-23-c01_2010d255.he5 MLS-Aura_L2GP-BrO_v02-23-c01_2010d255.he5
echo "1.2 MLS multiple swathes "
TEST -f MLS-Aura_L2GP-Temperature_v02-23-c01_2010d058.txt MLS-Aura_L2GP-Temperature_v02-23-c01_2010d058.he5 MLS-Aura_L2GP-Temperature_v02-23-c01_2010d058.he5
echo "1.3 HIRLDS zonal average "
TEST -f HIRza.txt HIR3ZA-test2.he5 HIR3ZA-test2.he5


echo "2.  OMI files"
echo "2.1 OMI swath (Scale data of one dimension are obtained from an ASCII file)"
TEST -f OMI-Aura_L2-OMBRO_2010m1005t1835-o33108_v003-2010m1006t023445.txt OMI-Aura_L2-OMBRO_2010m1005t1835-o33108_v003-2010m1006t023445.he5 OMI-Aura_L2-OMBRO_2010m1005t1835-o33108_v003-2010m1006t023445.he5

echo "2.2 OMI grid "
TEST -f OMI-Aura_L3-OMAEROe_2010m0830_v003-2010m0902t032205.txt OMI-Aura_L3-OMAEROe_2010m0830_v003-2010m0902t032205.he5 OMI-Aura_L3-OMAEROe_2010m0830_v003-2010m0902t032205.he5

echo "3.  TES files"
echo "3.1 TES swath (Scale data of one dimension are obtained from an ASCII file)"
TEST -f TES-Aura_L2-SUPPLEMENTAL-SO_r0000011860_C01_F01_07.txt TES-Aura_L2-SUPPLEMENTAL-SO_r0000011860_C01_F01_07.he5 TES-Aura_L2-SUPPLEMENTAL-SO_r0000011860_C01_F01_07.he5

echo "3.2 TES grid "
TEST -f TES-Aura_L3-O3_r0000011812_C01_F01_07.txt TES-Aura_L3-O3_r0000011812_C01_F01_07.he5 TES-Aura_L3-O3_r0000011812_C01_F01_07.he5

echo "4.  MOPITT files"
echo "4.1 MOPITT swath "
TEST -f MOP02J-20130830-L2V16.2.3.txt MOP02J-20130830-L2V16.2.3.he5 MOP02J-20130830-L2V16.2.3.he5

echo "4.2 MOPITT grid "
TEST -f MOP03N-20000303-L3V4.2.2.txt MOP03N-20000303-L3V4.2.2.he5 MOP03N-20000303-L3V4.2.2.he5


cp tmp_file_backup/*.he5 .
rm -rf tmp_file_backup

echo " "
echo "All NASA file tests with the file or the index option have passed"
echo " "


cd ../..
