/* 
 Copyright by The HDF Group.
 All rights reserved.                                                      
                                                                           
 This file is part of the HDF-EOS5 Augmentation Tool. The full HDF-EOS5 
 Augmentation Tool copyright notice including terms governing use, modification,
 and redistribution, is contained in the file COPYING.     
 COPYING can be found at the root of the source code    
 distribution tree. If you do not have access to this file, you may request
 a copy from eoshelp@hdfgroup.org. 
*/
#include <stdlib.h>
#include <stdio.h>
#include <netcdf.h>
#include <assert.h>
#include <netcdf.h>
#include <string.h>

extern char *optarg;
extern int optind;
extern int optopt;

void handle_error(int status) {
if (status != NC_NOERR) {
   fprintf(stderr, "%s\n", nc_strerror(status));
   exit(-1);
   }
}


int main(int argc, char *argv[])
{
	char *groups[4];
	int c = 0;

	size_t dimlen[NC_MAX_VAR_DIMS];
	int ncid[5];
        int ndims = -1;
        int dimids[NC_MAX_VAR_DIMS];
        int varid = 0;

	int i = 0; 
        int j = 0;
        int retval = 0;

 	char* VARNAME = NULL;
        char* FILENAME = NULL;

	int type = 0;
        int not_pure_dim = -1;
	
	groups[0] = "HDFEOS";
	groups[3] = "Data Fields";

	if(argc==1) /* no command line arguments */
	{
                groups[1] = "SWATHS";
                groups[2] = "HIRDLS";
                VARNAME = "CFC11";
	} else 
	{
		while ((c = getopt (argc, argv, "t:g:v:")) != -1)
		{        
	 	switch (c)
           	{
           	case 't':
	     	type = atoi(optarg);
	     	if(type==0)
			groups[1] = "SWATHS";
	     	else if(type==1)
			groups[1] = "GRIDS";
	     	else if(type==2)
			groups[1] = "ZAS";	
            	break;
         	case 'g':
             	groups[2] = optarg;
             	break;
           	case 'v':
	     	VARNAME = optarg;
	     	break;
	   	case '?':
	     	if(optopt=='t' || optopt=='n' ||optopt=='v')
	       		fprintf(stderr, "Option -%c requires an argument.\n", optopt);
            	else if (isprint (optopt))
               		fprintf (stderr, "Unknown option `-%c'.\n", optopt);
             	else
               		fprintf (stderr, "Unknown option character `\\x%x'.\n",
                        optopt);
             	return 1;
	   	default:
	     	abort();
	   	}
		}
	}

	if(argc==1)
		FILENAME = "single_swath_2.he5";
	else
		FILENAME = argv[optind];

	printf("Checking ");
	for(i=0; i<4; i++)
	  printf("/%s", groups[i]);
	printf("/%s", VARNAME);
     	printf(" in %s.\n\n", FILENAME);

	retval = nc_open(FILENAME, 0, &ncid[0]);
	if(retval != NC_NOERR) handle_error(retval);

	for(i=1; i<=4; i++)
	{
		retval = nc_inq_ncid(ncid[i-1], groups[i-1], &ncid[i]);
		if(retval != NC_NOERR) handle_error(retval);
	}

	retval = nc_inq_varid(ncid[4], VARNAME, &varid);
	if(retval != NC_NOERR) handle_error(retval);

	retval = nc_inq_varndims(ncid[4], varid, &ndims);
	if(retval != NC_NOERR) handle_error(retval);
	printf("No. of dimension(s): %d\n", ndims);

	retval = nc_inq_vardimid(ncid[4], varid, dimids);
	if(retval != NC_NOERR) handle_error(retval);

        retval = nc_inq_varids(ncid[3],&not_pure_dim,NULL);
        if(retval !=NC_NOERR) handle_error(retval);


	for(i=0; i<ndims; i++)
	{
	  char buf[NC_MAX_NAME+1];
	  float values[10240];
	  size_t start[]={0};
	  int dimvarid;

	  retval = nc_inq_dimname(ncid[4], dimids[i], buf);
	  if(retval != NC_NOERR) handle_error(retval);	
	  
	  retval = nc_inq_dimlen(ncid[4], dimids[i], &dimlen[i]);
          if(retval != NC_NOERR) handle_error(retval);
	  printf("  Dim[%d]: %s %lu\n", i, buf, dimlen[i]);
	 
          if(not_pure_dim >0) {
	  retval = nc_inq_varid(ncid[3], buf, &dimvarid);
	  if(retval != NC_NOERR) handle_error(retval);
	  /* printf("   ** dimvarid=%d, dimids[%i]=%d\n", dimvarid, i, dimids[i]); */
		
	  retval = nc_get_vara_float(ncid[3], dimvarid, start, &dimlen[i], values);
  	  if(retval != NC_NOERR) handle_error(retval);
	  printf("    ");
	  for(j=0; j<dimlen[i]; j++)
	  {
	    printf("%5.2f  ", values[j]);
	    if (j>10)
	      break;
	  }
	  printf("\n");
          }

	}

	{
	  size_t size = 1;
	  size_t *start = malloc(sizeof(int)*ndims);
	  for(i=0; i<ndims; i++) {
	    size *= dimlen[i];
	    start[i] = 0;
	  }
  	  float *values = (float*)malloc(sizeof(float)*size);
   	  size_t *count = dimlen;
	  retval = nc_get_vara_float(ncid[4], varid, start, count, (float*)values);
	  if(retval != NC_NOERR) handle_error(retval);
	  printf("Values:\n");
	  printf("    ");
	  for(i=0; i<10; i++) 
	  {
	    if(i>size-1)
	      break;
	    printf("%5.10f  ", values[i]);
	  }
	  printf("\n");
	  free(start);
	  free(values);
	}

	{
  	  float m;
	  char str[1024];

	  printf("Attributes:\n");
          memset(str, 0, sizeof(str));
	  retval = nc_get_att_text(ncid[4], varid, "Units", str);
	  if(retval != NC_NOERR) handle_error(retval);  
	
	  printf("  Units=%s\n", str);

	  retval = nc_get_att_text(ncid[4], varid, "Title", str);
	  if(retval != NC_NOERR) handle_error(retval);  
          printf("  Title=%s\n", str);
	}

	return 0;
}
