! Copyright by The HDF Group.
! All rights reserved.                                                      
!                                                                           
! This file is part of the HDF-EOS5 Augmentation Tool. The full HDF-EOS5 
! Augmentation Tool copyright notice including terms governing use, 
! modification, and redistribution, is contained in the file COPYING. 
! COPYING can be found at the root of the 
! source code distribution tree. If you do not have access to this file, you 
! may request a copy from eoshelp@hdfgroup.org. 

program check_f
  use netcdf
  implicit none

  character * (80) arg
  integer retval, ncid, ncid1, ncid2, ncid3, ncid4, varid
  real values(133)
  integer numDims, numAtts
  real missingvalue
  character(len=70) filename
  character(len=50) units
  integer dimids(1), dimvarids(1)
  character(len=100) name
  integer len
  real val_levels(133)
  real rhValue

  filename = 'single_zonal_average.he5'
  write(*,*) filename

  call check(nf90_open(filename, NF90_NOWRITE, ncid))
  call check(nf90_inq_ncid(ncid, "HDFEOS", ncid1))
  call check(nf90_inq_ncid(ncid1, "ZAS", ncid2))
  call check(nf90_inq_ncid(ncid2, "HIRDLS", ncid3))
  call check(nf90_inq_ncid(ncid3, "Data Fields", ncid4))
  call check(nf90_inq_varid(ncid4, "Day", varid))

  write(*,*) "/HDFEOS/ZAS/HIRDLS/Data Fields/Day"
  call check(nf90_inquire_variable(ncid4, varid, ndims = numDims, natts = numAtts, dimids = dimids))
  write(*,*), "numDims=: ", numDims, ", numAtts=", numAtts
  write(*,*), "DimIDs=: ", dimids(1)


  call check(nf90_inquire_dimension(ncid4, dimids(1), name, len))
  call check(nf90_inq_varid(ncid3, name, dimvarids(1)))
  write(*,*), "Dimension=:", name, "len=: ", len, "dimvarid=:", dimvarids(1)
  call check(nf90_get_var(ncid3, dimvarids(1),  val_levels))
  write(*,*) "  ", name, "=", val_levels(1), val_levels(2), val_levels(3), val_levels(4)

  call check(nf90_get_var(ncid4, varid, values))
  write(*,*) "  Day=: ", values(1), values(2), values(3), "..."
  call check(nf90_get_att(ncid4, varid, "MissingValue", missingvalue))
  write(*,*) "  Day::MissingValue=", missingvalue
  call check(nf90_get_att(ncid4, varid, "Units", units))
  write(*,*) "  Day::Units=", units

  call check(nf90_close(ncid))
  stop 

contains
  ! Internal subroutine - checks error status after each netcdf, prints out text message each time
  !   an error code is returned. 
  subroutine check(status)
    integer, intent ( in) :: status
    
    if(status /= nf90_noerr) then 
      print *, trim(nf90_strerror(status))
      stop 2
    end if
  end subroutine check  
end program check_f

